//LabPlot : AverageListDialog.h

#ifndef AVERAGELISTDIALOG_H
#define AVERAGELISTDIALOG_H

#include "ListDialog.h"

class AverageListDialog : public ListDialog
{
	Q_OBJECT
public:
	AverageListDialog(MainWin *mw, const char *name);
public slots:
	void setN(int n) { nni->setValue(n); }		//!< set number of points to average
	void Apply() { apply_clicked(); }
private:
	KIntNumInput *nni;
private slots:
	void saveSettings();
	int apply_clicked();
};

#endif // AVERAGELISTDIALOG_H
